@@ -1,5 +1,7 @@
 package PPIx::EditorTools;
-
+our $AUTHORITY = 'cpan:YANICK';
+# ABSTRACT: Utility methods and base class for manipulating Perl via PPI
+$PPIx::EditorTools::VERSION = '0.20';
 use 5.008;
 use strict;
 use warnings;
@@ -12,34 +14,6 @@ use Class::XSAccessor 1.02 constructor => 'new', accessors => {
 use PPI 1.203;
 use PPIx::EditorTools::ReturnObject;
 
-our $VERSION = '0.19';
-
-=pod
-
-=head1 NAME
-
-PPIx::EditorTools - Utility methods and base class for manipulating Perl via PPI
-
-=head1 SYNOPSIS
-
-    See PPIx::EditorTools::*
-
-=head1 DESCRIPTION
-
-Base class and utility methods for manipulating Perl via PPI. Pulled out from
-the C<Padre::Task::PPI> code.
-
-=head1 METHODS
-
-=over 4
-
-=item new()
-
-Constructor. Generally shouldn't be called with any arguments.
-
-=back
-
-=cut
 
 # Used by all the PPIx::EditorTools::* modules
 # Checks for either PPI::Document or take the code as a string and
@@ -95,7 +69,6 @@ sub find_unmatched_brace {
 # and line 6 col 7.
 sub get_all_variable_declarations {
 	my $document = shift;
-	my %vars;
 
 	my $declarations = $document->find(
 		sub {
@@ -346,36 +319,79 @@ sub find_variable_declaration {
 
 1;
 
-__END__
-
 =pod
 
-=head1 AUTHORS
+=encoding UTF-8
 
-Gabor Szabo E<lt>gabor@szabgab.comE<gt>
+=head1 NAME
 
-=head2 CONTRIBUTORS
+PPIx::EditorTools - Utility methods and base class for manipulating Perl via PPI
 
-ADAMK
+=head1 VERSION
 
-AZAWAWI
+version 0.20
 
-BOWTIE
+=head1 SYNOPSIS
 
-buff3r
+    See PPIx::EditorTools::*
 
-MGRIMES
+=head1 DESCRIPTION
 
-PATRICKAS
+Base class and utility methods for manipulating Perl via PPI. Pulled out from
+the C<Padre::Task::PPI> code.
 
-SMUELLER
+=head1 METHODS
+
+=over 4
+
+=item new()
+
+Constructor. Generally shouldn't be called with any arguments.
+
+=back
 
 =head1 SEE ALSO
 
 C<PPIx::EditorTools::*>, L<Padre>, L<App::EditorTools>, L<Padre>, and L<PPI>.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Steffen Mueller C<smueller@cpan.org>
+
+=item *
+
+Mark Grimes C<mgrimes@cpan.org>
+
+=item *
+
+Ahmad M. Zawawi <ahmad.zawawi@gmail.com>
+
+=item *
+
+Gabor Szabo  <gabor@szabgab.com>
+
+=item *
+
+Yanick Champoux <yanick@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017, 2014, 2012 by The Padre development team as listed in Padre.pm..
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
+__END__
+
+
 # Copyright 2008-2009 The Padre development team as listed in Padre.pm.
 # LICENSE
 # This program is free software; you can redistribute it and/or
